@@ -1,5 +1,5 @@
 """Tag and node definition for the built-in "for" tag."""
-
+from __future__ import annotations
 import sys
 
 from typing import Optional
@@ -43,6 +43,7 @@ ENDFORBLOCK = (TAG_ENDFOR, TAG_ELSE)
 ENDFORELSEBLOCK = (TAG_ENDFOR,)
 
 
+# pylint: disable=too-many-instance-attributes
 class ForLoop(Mapping[str, object]):
     """Loop helper variables."""
 
@@ -58,9 +59,16 @@ class ForLoop(Mapping[str, object]):
         "rindex",
         "rindex0",
         "_keys",
+        "parentloop",
     )
 
-    def __init__(self, name: str, it: Iterator[Any], length: int):
+    def __init__(
+        self,
+        name: str,
+        it: Iterator[Any],
+        length: int,
+        parentloop: object,
+    ):
         self.name = name
         self.it = it
         self.length = length
@@ -72,6 +80,7 @@ class ForLoop(Mapping[str, object]):
         self.index0 = -1
         self.rindex = self.length + 1
         self.rindex0 = self.length
+        self.parentloop = parentloop
 
         self._keys: List[str] = [
             "length",
@@ -81,6 +90,7 @@ class ForLoop(Mapping[str, object]):
             "rindex0",
             "first",
             "last",
+            "parentloop",
         ]
 
     def __repr__(self) -> str:  # pragma: no cover
@@ -123,8 +133,6 @@ class ForLoop(Mapping[str, object]):
         else:
             self.last = False
 
-        return None
-
 
 class ForNode(Node):
     """Parse tree node for the built-in "for" tag."""
@@ -161,6 +169,7 @@ class ForNode(Node):
                 name=name,
                 it=loop_iter,
                 length=length,
+                parentloop=context.parentloop(),
             )
 
             namespace = {
@@ -170,7 +179,7 @@ class ForNode(Node):
 
             # Extend the context. Essentially giving priority to `ForLoopDrop`, then
             # delegating `get` and `assign` to the outer context.
-            with context.extend(namespace):
+            with context.loop(namespace, forloop):
 
                 for itm in forloop:
                     namespace[name] = itm
@@ -183,9 +192,9 @@ class ForNode(Node):
                         break
 
         elif self.default:
-            self.default.render(context, buffer)
+            return self.default.render(context, buffer)
 
-        return None
+        return True
 
     async def render_to_output_async(
         self, context: Context, buffer: TextIO
@@ -199,6 +208,7 @@ class ForNode(Node):
                 name=name,
                 it=loop_iter,
                 length=length,
+                parentloop=context.parentloop(),
             )
 
             namespace = {
@@ -208,7 +218,7 @@ class ForNode(Node):
 
             # Extend the context. Essentially giving priority to `ForLoopDrop`, then
             # delegating `get` and `assign` to the outer context.
-            with context.extend(namespace):
+            with context.loop(namespace, forloop):
 
                 for itm in forloop:
                     namespace[name] = itm
@@ -221,9 +231,9 @@ class ForNode(Node):
                         break
 
         elif self.default:
-            await self.default.render_async(context, buffer)
+            return await self.default.render_async(context, buffer)
 
-        return None
+        return True
 
 
 class BreakNode(Node):
