@@ -86,7 +86,7 @@ class IfNode(Node):
 
     def render_to_output(self, context: Context, buffer: TextIO) -> Optional[bool]:
         if self.condition.evaluate(context):
-            self.consequence.render(context, buffer)
+            rendered = self.consequence.render(context, buffer)
         else:
             rendered = False
             for alt in self.conditional_alternatives:
@@ -95,15 +95,15 @@ class IfNode(Node):
                     break
 
             if not rendered and self.alternative:
-                self.alternative.render(context, buffer)
+                return self.alternative.render(context, buffer)
 
-        return None
+        return rendered
 
     async def render_to_output_async(
         self, context: Context, buffer: TextIO
     ) -> Optional[bool]:
         if await self.condition.evaluate_async(context):
-            await self.consequence.render_async(context, buffer)
+            rendered = await self.consequence.render_async(context, buffer)
         else:
             rendered = False
             for alt in self.conditional_alternatives:
@@ -112,9 +112,9 @@ class IfNode(Node):
                     break
 
             if not rendered and self.alternative:
-                await self.alternative.render_async(context, buffer)
+                return await self.alternative.render_async(context, buffer)
 
-        return None
+        return rendered
 
 
 class IfTag(Tag):
@@ -127,7 +127,9 @@ class IfTag(Tag):
         super().__init__(env)
         self.parser = get_parser(self.env)
 
+    # pylint: disable=no-self-use
     def parse_expression(self, stream: TokenStream) -> Expression:
+        """Pare a boolean expression from a stream of tokens."""
         expect(stream, TOKEN_EXPRESSION)
         expr_iter = tokenize_boolean_expression(stream.current.value)
         return parse_boolean_expression(TokenStream(expr_iter))
@@ -143,13 +145,16 @@ class IfTag(Tag):
         consequence = self.parser.parse_block(stream, ENDIFBLOCK)
         conditional_alternatives = []
 
+        parse_block = self.parser.parse_block
+        parse_expression = self.parse_expression
+
         while stream.current.istag(TAG_ELSIF):
             stream.next_token()
 
             # If the expression can't be parsed, eat the "elsif" block and
             # continue to parse more "elsif" expression, if any.
             try:
-                expr = self.parse_expression(stream)
+                expr = parse_expression(stream)
             except LiquidSyntaxError as err:
                 self.env.error(err)
                 eat_block(stream, ENDELSIFBLOCK)
@@ -157,7 +162,7 @@ class IfTag(Tag):
 
             alt_tok = stream.current
             stream.next_token()
-            alt_block = self.parser.parse_block(stream, ENDELSIFBLOCK)
+            alt_block = parse_block(stream, ENDELSIFBLOCK)
 
             conditional_alternatives.append(
                 ConditionalBlockNode(alt_tok, condition=expr, block=alt_block)
@@ -167,7 +172,7 @@ class IfTag(Tag):
 
         if stream.current.istag(TAG_ELSE):
             stream.next_token()
-            alternative = self.parser.parse_block(stream, ENDIFELSEBLOCK)
+            alternative = parse_block(stream, ENDIFELSEBLOCK)
 
         expect(stream, TOKEN_TAG, value=TAG_ENDIF)
         return IfNode(
