@@ -1,3 +1,4 @@
+"""Liquid tag base class."""
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
@@ -10,7 +11,7 @@ from liquid.exceptions import Error
 from liquid.parse import eat_block
 from liquid.stream import TokenStream
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from liquid import Environment
 
 
@@ -42,4 +43,4 @@ class Tag(ABC):
 
     @abstractmethod
     def parse(self, stream: TokenStream) -> Node:
-        """Return a parse tree node py parsing tokens from the given stream."""
+        """Return a parse tree node by parsing tokens from the given stream."""
